@@ -1,11 +1,10 @@
+-- support for i18n
+local S = armor_i18n.gettext
+
 if not minetest.get_modpath("technic") then
-	minetest.log("warning", "hazmat_suit: Mod loaded but unused.")
+	minetest.log("warning", S("hazmat_suit: Mod loaded but unused."))
 	return
 end
-local S = function(s) return s end
-if minetest.global_exists("intllib") then
-	S = intllib.Getter()
-end
 
 minetest.register_craftitem("hazmat_suit:helmet_hazmat", {
 		description = S("Hazmat Helmet"),
